@@ -8,7 +8,7 @@ use {
         app::*,
         conf::Conf,
         errors::ConfError,
-        keys,
+        keys::KEY_FORMAT,
     },
     crossterm::event::KeyEvent,
 };
@@ -57,14 +57,14 @@ impl VerbStore {
     ) -> PrefixSearchResult<'v, &Verb> {
         let stype = sel_info.common_stype();
         let count = sel_info.count_paths();
-        self.search(prefix, stype, Some(count))
+        self.search(prefix, stype, Some(count), sel_info.extension())
     }
 
     pub fn search_prefix<'v>(
         &'v self,
         prefix: &str,
     ) -> PrefixSearchResult<'v, &Verb> {
-        self.search(prefix, None, None)
+        self.search(prefix, None, None, None)
     }
 
     pub fn search<'v>(
@@ -72,6 +72,7 @@ impl VerbStore {
         prefix: &str,
         stype: Option<SelectionType>,
         sel_count: Option<usize>,
+        extension: Option<&str>,
     ) -> PrefixSearchResult<'v, &Verb> {
         let mut found_index = 0;
         let mut nb_found = 0;
@@ -101,6 +102,11 @@ impl VerbStore {
                     continue;
                 }
             }
+            if !verb.file_extensions.is_empty() {
+                if !extension.map_or(false, |ext| verb.file_extensions.iter().any(|ve| ve == ext)) {
+                    continue;
+                }
+            }
         }
         match nb_found {
             0 => PrefixSearchResult::NoMatch,
@@ -128,7 +134,7 @@ impl VerbStore {
     ) -> Option<String> {
         for verb in &self.verbs {
             if verb.get_internal() == Some(internal) && stype.respects(verb.selection_condition) {
-                return verb.keys.get(0).map(|&k| keys::key_event_desc(k));
+                return verb.keys.get(0).map(|&k| KEY_FORMAT.to_string(k));
             }
         }
         None
@@ -140,7 +146,7 @@ impl VerbStore {
     ) -> Option<String> {
         for verb in &self.verbs {
             if verb.get_internal() == Some(internal) {
-                return verb.keys.get(0).map(|&k| keys::key_event_desc(k));
+                return verb.keys.get(0).map(|&k| KEY_FORMAT.to_string(k));
             }
         }
         None
